"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

function _client() {
  const data = require("@nocobase/client");

  _client = function _client() {
    return data;
  };

  return data;
}

var _CollectionBlockInitializer = require("../../components/CollectionBlockInitializer");

var _CollectionFieldInitializers = require("../../components/CollectionFieldInitializers");

var _variable = require("../../variable");

var _locale = require("../../locale");

var _SchemaConfig = require("./SchemaConfig");

var _ModeConfig = require("./ModeConfig");

var _AssigneesSelect = require("./AssigneesSelect");

const MULTIPLE_ASSIGNED_MODE = {
  SINGLE: Symbol('single'),
  ALL: Symbol('all'),
  ANY: Symbol('any'),
  ALL_PERCENTAGE: Symbol('all percentage'),
  ANY_PERCENTAGE: Symbol('any percentage')
}; // TODO(optimize): change to register way

const initializerGroup = _client().BlockInitializers.items.find(group => group.key === 'media');

if (!initializerGroup.children.find(item => item.key === 'workflowTodos')) {
  initializerGroup.children.push({
    key: 'workflowTodos',
    type: 'item',
    title: `{{t("Workflow todos", { ns: "${_locale.NAMESPACE}" })}}`,
    component: 'WorkflowTodoBlockInitializer',
    icon: 'CheckSquareOutlined'
  });
}

var _default = {
  title: `{{t("Manual", { ns: "${_locale.NAMESPACE}" })}}`,
  type: 'manual',
  group: 'manual',
  fieldset: {
    assignees: {
      type: 'array',
      title: `{{t("Assignees", { ns: "${_locale.NAMESPACE}" })}}`,
      'x-decorator': 'FormItem',
      'x-component': 'AssigneesSelect',
      'x-component-props': {// multiple: true,
      },
      required: true,
      default: []
    },
    mode: {
      type: 'number',
      title: `{{t("Mode", { ns: "${_locale.NAMESPACE}" })}}`,
      'x-decorator': 'FormItem',
      'x-component': 'ModeConfig',
      default: 1,
      'x-reactions': {
        dependencies: ['assignees'],
        fulfill: {
          state: {
            visible: '{{$deps[0].length > 1}}'
          }
        }
      }
    },
    schema: {
      type: 'void',
      title: `{{t("User interface", { ns: "${_locale.NAMESPACE}" })}}`,
      'x-decorator': 'FormItem',
      'x-component': 'SchemaConfigButton',
      properties: {
        schema: {
          type: 'object',
          'x-component': 'SchemaConfig'
        }
      }
    }
  },
  view: {},
  scope: {},
  components: {
    SchemaConfigButton: _SchemaConfig.SchemaConfigButton,
    SchemaConfig: _SchemaConfig.SchemaConfig,
    ModeConfig: _ModeConfig.ModeConfig,
    AssigneesSelect: _AssigneesSelect.AssigneesSelect
  },

  getOptions(config, types) {
    var _config$schema$collec, _config$schema, _config$schema$collec2;

    const fields = ((_config$schema$collec = (_config$schema = config.schema) === null || _config$schema === void 0 ? void 0 : (_config$schema$collec2 = _config$schema.collection) === null || _config$schema$collec2 === void 0 ? void 0 : _config$schema$collec2.fields) !== null && _config$schema$collec !== void 0 ? _config$schema$collec : []).map(field => ({
      key: field.name,
      value: field.name,
      label: field.uiSchema.title,
      title: field.uiSchema.title
    }));
    const filteredFields = (0, _variable.filterTypedFields)(fields, types);
    return filteredFields.length ? filteredFields : null;
  },

  useInitializers(node) {
    var _node$config$schema, _node$config$schema$c, _node$config$schema$c2, _node$title;

    if (!((_node$config$schema = node.config.schema) === null || _node$config$schema === void 0 ? void 0 : (_node$config$schema$c = _node$config$schema.collection) === null || _node$config$schema$c === void 0 ? void 0 : (_node$config$schema$c2 = _node$config$schema$c.fields) === null || _node$config$schema$c2 === void 0 ? void 0 : _node$config$schema$c2.length) || node.config.mode) {
      return null;
    }

    return {
      type: 'item',
      title: (_node$title = node.title) !== null && _node$title !== void 0 ? _node$title : `#${node.id}`,
      component: _CollectionBlockInitializer.CollectionBlockInitializer,
      collection: node.config.schema.collection,
      dataSource: `{{$jobsMapByNodeId.${node.id}}}`
    };
  },

  initializers: {
    CollectionFieldInitializers: _CollectionFieldInitializers.CollectionFieldInitializers
  }
};
exports.default = _default;