"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TypeSets = void 0;
exports.filterTypedFields = filterTypedFields;
exports.useCollectionFieldOptions = useCollectionFieldOptions;
exports.useWorkflowVariableOptions = useWorkflowVariableOptions;

function _client() {
  const data = require("@nocobase/client");

  _client = function _client() {
    return data;
  };

  return data;
}

var _nodes = require("./nodes");

var _FlowContext = require("./FlowContext");

var _triggers = require("./triggers");

var _locale = require("./locale");

const VariableTypes = [{
  title: `{{t("Node result", { ns: "${_locale.NAMESPACE}" })}}`,
  value: '$jobsMapByNodeId',

  options(types) {
    const current = (0, _nodes.useNodeContext)();
    const upstreams = (0, _nodes.useAvailableUpstreams)(current);
    const options = [];
    upstreams.forEach(node => {
      var _instruction$getOptio;

      const instruction = _nodes.instructions.get(node.type);

      const subOptions = (_instruction$getOptio = instruction.getOptions) === null || _instruction$getOptio === void 0 ? void 0 : _instruction$getOptio.call(instruction, node.config, types);

      if (subOptions) {
        var _node$title;

        options.push({
          key: node.id.toString(),
          value: node.id.toString(),
          label: (_node$title = node.title) !== null && _node$title !== void 0 ? _node$title : `#${node.id}`,
          children: subOptions
        });
      }
    });
    return options;
  }

}, {
  title: `{{t("Trigger variables", { ns: "${_locale.NAMESPACE}" })}}`,
  value: '$context',

  options(types) {
    var _trigger$getOptions, _trigger$getOptions2;

    const _useFlowContext = (0, _FlowContext.useFlowContext)(),
          workflow = _useFlowContext.workflow;

    const trigger = _triggers.triggers.get(workflow.type);

    return (_trigger$getOptions = trigger === null || trigger === void 0 ? void 0 : (_trigger$getOptions2 = trigger.getOptions) === null || _trigger$getOptions2 === void 0 ? void 0 : _trigger$getOptions2.call(trigger, workflow.config, types)) !== null && _trigger$getOptions !== void 0 ? _trigger$getOptions : null;
  }

}, {
  title: `{{t("System variables", { ns: "${_locale.NAMESPACE}" })}}`,
  value: '$system',
  options: [{
    key: 'now',
    value: 'now',
    label: `{{t("Current time", { ns: "${_locale.NAMESPACE}" })}}`
  }]
}];
const TypeSets = {
  boolean: new Set(['boolean']),
  number: new Set(['integer', 'bigInt', 'float', 'double', 'real', 'decimal']),
  string: new Set(['string', 'text', 'password']),
  date: new Set(['date', 'time'])
};
exports.TypeSets = TypeSets;

function matchFieldType(field, type) {
  if (typeof type === 'string') {
    var _TypeSets$type;

    return Boolean((_TypeSets$type = TypeSets[type]) === null || _TypeSets$type === void 0 ? void 0 : _TypeSets$type.has(field.type));
  }

  if (typeof type === 'object' && type.type === 'reference') {
    var _type$options, _type$options2;

    return field.collectionName === ((_type$options = type.options) === null || _type$options === void 0 ? void 0 : _type$options.collection) && field.name === 'id' || field.type === 'belongsTo' && field.target === ((_type$options2 = type.options) === null || _type$options2 === void 0 ? void 0 : _type$options2.collection);
  }

  return false;
}

function filterTypedFields(fields, types) {
  return types ? fields.filter(field => types.some(type => matchFieldType(field, type))) : fields;
}

function useWorkflowVariableOptions() {
  const compile = (0, _client().useCompile)();
  const options = VariableTypes.map(item => {
    const options = typeof item.options === 'function' ? item.options().filter(Boolean) : item.options;
    return {
      label: compile(item.title),
      value: item.value,
      key: item.value,
      children: compile(options),
      disabled: options && !options.length
    };
  });
  return options;
}

function useCollectionFieldOptions(props) {
  const fields = props.fields,
        collection = props.collection,
        types = props.types;
  const compile = (0, _client().useCompile)();

  const _useCollectionManager = (0, _client().useCollectionManager)(),
        getCollectionFields = _useCollectionManager.getCollectionFields;

  return filterTypedFields(fields !== null && fields !== void 0 ? fields : getCollectionFields(collection), types).filter(field => field.interface && (!field.target || field.type === 'belongsTo')).map(field => {
    var _field$uiSchema, _field$uiSchema2;

    return field.type === 'belongsTo' ? {
      label: `${compile(((_field$uiSchema = field.uiSchema) === null || _field$uiSchema === void 0 ? void 0 : _field$uiSchema.title) || field.name)} ID`,
      key: field.foreignKey,
      value: field.foreignKey
    } : {
      label: compile(((_field$uiSchema2 = field.uiSchema) === null || _field$uiSchema2 === void 0 ? void 0 : _field$uiSchema2.title) || field.name),
      key: field.name,
      value: field.name
    };
  });
}